(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     55080,       1487]
NotebookOptionsPosition[     15036,        556]
NotebookOutlinePosition[     50924,       1349]
CellTagsIndexPosition[     50845,       1344]
WindowTitle->Development: Test-Driven Development
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["\<\
Development: Test-Driven Development\
\>", "Title",
 CellChangeTimes->{{3.519384601465209*^9, 3.519384613486219*^9}, {
   3.525618961682146*^9, 3.5256189624154453`*^9}, 3.53764009078034*^9}],

Cell["\<\
Adam Berry
Wolfram Research
training@wolfram.com\
\>", "Subsubtitle",
 CellChangeTimes->{{3.5376400940883403`*^9, 3.5376400954623404`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Contents", "OverviewTitle"],

Cell["Introducing MUnit", "OverviewSection",
 CellChangeTimes->{{3.519389774765862*^9, 3.519389791194903*^9}}],

Cell[TextData[{
 StyleBox["Workbench",
  FontSlant->"Italic"],
 " Testing Tools"
}], "OverviewSection",
 CellChangeTimes->{{3.5193898366565638`*^9, 3.519389845951676*^9}}],

Cell["Test First Functions", "OverviewSection",
 CellChangeTimes->{{3.519389848423724*^9, 3.519389855271027*^9}, {
  3.519480535046026*^9, 3.519480536361589*^9}}],

Cell["Testing Strategies", "OverviewSection",
 CellChangeTimes->{{3.519481085736411*^9, 3.5194810923601513`*^9}}],

Cell["Deploying and Reporting Tests", "OverviewSection",
 CellChangeTimes->{{3.51938985641574*^9, 3.5193898886931887`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Introducing MUnit", "Section",
 CellChangeTimes->{3.519646461758213*^9}],

Cell[CellGroupData[{

Cell["About", "Subsection",
 CellChangeTimes->{{3.51964694692649*^9, 3.519646947574441*^9}}],

Cell[TextData[{
 "MUnit is a unit testing framework for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", similar in concept to testing frameworks for other languages such as \
JUnit for Java."
}], "Text",
 CellChangeTimes->{{3.5218140229517307`*^9, 3.521814025175811*^9}, {
  3.521814058592128*^9, 3.521814075724477*^9}, {3.521814120888503*^9, 
  3.521814167501699*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test Basics", "Subsection",
 CellChangeTimes->{{3.519646477500031*^9, 3.5196464837372437`*^9}, {
  3.5196468458209352`*^9, 3.519646847860338*^9}, {3.51964688421171*^9, 
  3.519646884802135*^9}}],

Cell[TextData[{
 "To create a test, we simply write ",
 StyleBox["Test", "MR"],
 " expressions, supplying the input to be evaluated, and the expected output. "
}], "Text",
 CellChangeTimes->{{3.521818943251045*^9, 3.521818969766679*^9}, {
  3.52182938457835*^9, 3.521829393063922*^9}}],

Cell["\<\
Test[
\t2+2
\t,
\t4
]\
\>", "Program",
 CellChangeTimes->{{3.5218295194657297`*^9, 3.52182953357521*^9}}],

Cell["\<\
The input will be evaluated, and its output will be compared to the expected \
output using SameQ.\
\>", "Text",
 CellChangeTimes->{{3.521829874036365*^9, 3.521829883258449*^9}, {
   3.5218299509905043`*^9, 3.52182995943771*^9}, {3.521829998995328*^9, 
   3.521830012738441*^9}, 3.521830172936754*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test Options and Flexibility", "Subsection",
 CellChangeTimes->{{3.519646908257491*^9, 3.5196469273372*^9}}],

Cell[CellGroupData[{

Cell["TestID", "Subsubsection",
 CellChangeTimes->{{3.521830466353702*^9, 3.521830467662869*^9}}],

Cell["\<\
TestID is an option that you will almost always use. Just as the name \
implies, it is to identify a test within a file, and the identifier must be a \
string unique in this file.\
\>", "Text"],

Cell["\<\
Test[
\t2+2
\t,
\t4
\t,
\tTestID -> \"MyTest1\"
]\
\>", "Program",
 CellChangeTimes->{{3.5218295194657297`*^9, 3.52182953357521*^9}, {
  3.5218321491487722`*^9, 3.5218321624104853`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["EquivalenceFunction", "Subsubsection",
 CellChangeTimes->{{3.521830588665658*^9, 3.52183059260886*^9}}],

Cell[TextData[{
 "You can change the function used to compare the output and expected output \
using the option ",
 StyleBox["EquivalenceFunction", "MR"]
}], "Text",
 CellChangeTimes->{{3.521832170820115*^9, 3.521832195920848*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Messages", "Subsection",
 CellChangeTimes->{{3.521830830500381*^9, 3.52183083169814*^9}}],

Cell["\<\
Creating messages for user feedback of trouble is a necessary part of \
function development. As with all other aspects of development, these should \
be tested to ensure that they are issued under the correct conditions.\
\>", "Text",
 CellChangeTimes->{{3.521930703554109*^9, 3.521930715633011*^9}, {
  3.521930795851818*^9, 3.521930898976993*^9}}],

Cell["\<\
Test[
\t1/0
\t,
\tComplexInfinity
\t,
\t{Power::infy}
\t,
\tTestID -> \"MyTest2\"
]\
\>", "Program",
 CellChangeTimes->{{3.521930912321031*^9, 3.521930967428071*^9}}],

Cell[TextData[{
 "Messages to test for are supplied in a list as the third argument to ",
 StyleBox["Test", "MR"],
 ". "
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Workbench",
  FontSlant->"Italic"],
 " Testing Tools"
}], "Section",
 CellChangeTimes->{{3.51964695125517*^9, 3.519646956405973*^9}}],

Cell[CellGroupData[{

Cell["Test Files", "Subsection",
 CellChangeTimes->{{3.519646973940974*^9, 3.519646975428832*^9}}],

Cell[TextData[{
 "There is a wizard to create a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " test file; these have the extension ",
 StyleBox["mt", "Program"],
 ", but are really just plain ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " source files that are executed by a special runner."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Templates, Fixes, and More", "Subsection"],

Cell["\<\
Writing tests is much easier and faster using code templates, available from \
the content assist in the code editor.\
\>", "Text",
 CellChangeTimes->{{3.52193109325019*^9, 3.521931115083997*^9}, {
  3.521931148329976*^9, 3.521931149648031*^9}, {3.522144804943618*^9, 
  3.522144831131702*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Executing Tests", "Subsection",
 CellChangeTimes->{{3.519647061281269*^9, 3.519647086086931*^9}}],

Cell[TextData[{
 "To run a single test file it\[CloseCurlyQuote]s as simple as right-clicking \
and choosing ",
 StyleBox["Run As \[FilledRightTriangle] ", "Menu"],
 StyleBox["Mathematica", "Menu",
  FontSlant->"Italic"],
 StyleBox[" Test", "Menu"],
 ". ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will launch, the tests will be executed, and the ",
 StyleBox["MUnit", "Menu"],
 " view will be updated with the results as they happen."
}], "Text"],

Cell[CellGroupData[{

Cell["Test Suites", "Subsubsection",
 CellChangeTimes->{{3.5219320063425713`*^9, 3.521932008464682*^9}}],

Cell[TextData[{
 "To group a set of test files together to make it easier to launch, you can \
create a .mt file that contains a ",
 StyleBox["TestSuite", "Progra"],
 " expression, which takes a list of file paths relative to the suite file."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examining Failures", "Subsection",
 CellChangeTimes->{{3.521931181412265*^9, 3.521931184820025*^9}}],

Cell["\<\
Right-clicking on a failure and choosing failure compare will open up an \
expression navigator that will allow you to see exactly which parts of your \
expression caused the failure.\
\>", "Text",
 CellChangeTimes->{{3.5381585825612*^9, 3.538158588259349*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Test Driven Functions", "Section",
 CellChangeTimes->{
  3.51964710239287*^9, {3.521933059620658*^9, 3.521933090250491*^9}}],

Cell[CellGroupData[{

Cell["Test and Then Function", "Subsection"],

Cell["\<\
Test driven development simply means that you write the test(s) for the \
function before you write the function. These tests form a specification for \
the function, and guide development.\
\>", "Text",
 CellChangeTimes->{{3.521933116978559*^9, 3.521933129898201*^9}, {
  3.521933377515218*^9, 3.521933395277706*^9}, {3.521933598529003*^9, 
  3.521933633565463*^9}}],

Cell["\<\
Test[
\tMakeMap[ {{a,b},{c,d},{e,f}} ]
\t,
\t{a->b,c->d,e->f}
]\
\>", "Program",
 CellChangeTimes->{{3.521933838385118*^9, 3.521933838912861*^9}, {
  3.5220957494144793`*^9, 3.522095757693149*^9}, {3.522095798994289*^9, 
  3.5220958458214684`*^9}, {3.52209689317889*^9, 3.522096893416216*^9}}],

Cell["\<\
Once we have the test for a function we can start writing it\
\>", "Text",
 CellChangeTimes->{{3.522095853221292*^9, 3.522095858476941*^9}, {
  3.522095980247011*^9, 3.5220959840293407`*^9}}],

Cell["\<\
MakeMap[{pair__?(Function[x,Length[x]===2])}]:=Map[Rule[First@#,Last@#]&,{\
pair}]\
\>", "Program",
 CellChangeTimes->{{3.522097068537464*^9, 3.5220970861667547`*^9}}],

Cell["\<\
By simply writing the test first, we have written the function in such a way \
so that the intended input is specified, so we write the definition to that, \
thus reducing the chance of errors due to unexpected input. \
\>", "Text",
 CellChangeTimes->{{3.522097091860681*^9, 3.522097097763949*^9}, {
  3.5220971332273006`*^9, 3.5220972082489634`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Green for Go and Repeat", "Subsection"],

Cell[TextData[{
 "Basically, you keep developing and running the tests until they all pass, \
which in the ",
 StyleBox["Workbench",
  FontSlant->"Italic"],
 " will give the green bar."
}], "Text",
 CellChangeTimes->{{3.521933677246397*^9, 3.52193376872019*^9}, 
   3.522093706375791*^9}],

Cell["\<\
Almost certainly at this point you will start again, writing tests, \
developing the function, and running tests until everything passes.\
\>", "Text",
 CellChangeTimes->{{3.521933769647533*^9, 3.521933808740851*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Testing Strategies", "Section",
 CellChangeTimes->{3.519647319515439*^9}],

Cell[CellGroupData[{

Cell["Public and Private Functions", "Subsection",
 CellChangeTimes->{{3.519647498112452*^9, 3.5196475090618353`*^9}}],

Cell["\<\
Normally, writing applications and packages results in functions that you \
export, and a significant number that you don\[CloseCurlyQuote]t, also called \
private functions. Ideally you should have test coverage of all code that you \
write. \
\>", "Text"],

Cell["\<\
Testing private functions is easy, there are a couple of options. First you \
can use the full context path for a function to test.\
\>", "Text",
 CellChangeTimes->{{3.5220924747167253`*^9, 3.522092487086645*^9}, {
  3.522092549398863*^9, 3.522092581637124*^9}}],

Cell["\<\
Test[
\tPackage`Private`MyFunction[]
\t,
\toutput
]\
\>", "Program",
 CellChangeTimes->{{3.522092654343586*^9, 3.522092675751892*^9}, {
  3.522092719574638*^9, 3.522092723204484*^9}}],

Cell["\<\
This is fine if you are only writing one or two tests in a file for private \
functions.\
\>", "Text",
 CellChangeTimes->{{3.522092729076832*^9, 3.5220927551706867`*^9}, {
  3.5220928893681297`*^9, 3.5220929040666018`*^9}}],

Cell["\<\
Begin[\"Package`Private`\"]

Test[
\tMyFunction[]
\t,
\toutput
]

End[]\
\>", "Program",
 CellChangeTimes->{{3.5220929166800213`*^9, 3.52209294517585*^9}}],

Cell[TextData[{
 "This would allow you to write tests for any functions that are in this \
private context between the ",
 Cell[BoxData[
  ButtonBox["Begin",
   BaseStyle->{"Link", "Text"},
   ButtonData->"paclet:ref/Begin"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox["End",
   BaseStyle->{"Link", "Text"},
   ButtonData->"paclet:ref/End"]], "InlineFormula"],
 " statements."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using Maximum Information", "Subsection",
 CellChangeTimes->{{3.519647518598751*^9, 3.5196475224129047`*^9}}],

Cell["\<\
It\[CloseCurlyQuote]s important to write tests in such a way that when they \
fail, you know exactly why. \
\>", "Text"],

Cell["\<\
Test[
\tHead[ MyFunction[] ]
\t,
\tList
]\
\>", "Program",
 CellChangeTimes->{{3.522093335907709*^9, 3.522093379558242*^9}}],

Cell[TextData[{
 "If this fails, all you will know is that the head of the output wasn\
\[CloseCurlyQuote]t ",
 Cell[BoxData[
  ButtonBox["List",
   BaseStyle->{"Link", "Text"},
   ButtonData->"paclet:ref/List"]], "InlineFormula"],
 ", which means that you will need to do additional work to determine the \
failure. Better would be:"
}], "Text"],

Cell["\<\
Test[
\tMyFunction[]
\t,
\t{{a,b},{c,d}}
]\
\>", "Program",
 CellChangeTimes->{{3.5220935031445303`*^9, 3.522093504774744*^9}, {
  3.5220935490730124`*^9, 3.522093567931114*^9}}],

Cell["\<\
If you had a failure with this version, you would instantly know which part \
of the expression didn\[CloseCurlyQuote]t match.\
\>", "Text",
 CellChangeTimes->{{3.522093579779045*^9, 3.522093601537197*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test Organization", "Subsection",
 CellChangeTimes->{{3.5196475380213823`*^9, 3.519647545540097*^9}}],

Cell["\<\
You could have a test file per function, a file per package in a folder \
hierarchy that matches the context hierarchy. The choice will depend on the \
scale of the project.\
\>", "Text",
 CellChangeTimes->{{3.522095284231804*^9, 3.522095297821679*^9}, {
  3.5220953908480453`*^9, 3.5220954213828087`*^9}, {3.522095464687003*^9, 
  3.522095472563653*^9}, {3.522095551862729*^9, 3.522095652304875*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Deploying and Reporting Tests", "Section",
 CellChangeTimes->{3.519647562063369*^9}],

Cell[CellGroupData[{

Cell["\<\
Running in a Build or Continuous Integration System\
\>", "Subsection"],

Cell["\<\
The MUnit application can simply be used from within a kernel session to \
start a test run, so launching tests on a set of files from almost any \
environment is very easy.\
\>", "Text",
 CellChangeTimes->{{3.522144563316906*^9, 3.5221446090650253`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test Result Reporting", "Subsection"],

Cell["\<\
MUnit supports test loggers. Included are ones for printing to standard out, \
and into a notebook file, which itself could be exported to PDF or HTML, etc. \
Additionally you could create a new logger to create the reporting format of \
your choice.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Saveable->True,
ScreenStyleEnvironment->"SlideShow",
WindowToolbars->{},
WindowSize->{1024, 768},
WindowMargins->Automatic,
WindowTitle->"Development: Test-Driven Development",
Magnification->1,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 15, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
       TextData[{"Style Definitions for \n", 
         StyleBox["Wolfram Seminars", FontSlant -> "Italic"]}], "Subtitle"], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]], 
      Cell[
       StyleData[StyleDefinitions -> "StyleMenuClear.nb"]], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Definitions", "Section"], 
         Cell[
          StyleData[
          All, "SlideShow", StyleDefinitions -> 
           StyleData[All, "Presentation"]], PageWidth -> WindowWidth, 
          DockedCells -> Cell[
            BoxData[
             GridBox[{{
                TooltipBox[
                 ButtonBox[
                  StyleBox[
                   RowBox[{"  ", "\[EmptySquare]", " "}], FontSize -> 20, 
                   GrayLevel[0.7]], Appearance -> None, 
                  ButtonFunction :> (
                   FEPrivate`NotebookToggleFullScreen[]; {}), Evaluator -> 
                  None], 
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "SlideshowToolbarText", "TooltipToggleFullScreen"]]], 
                StyleBox[
                 RowBox[{
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[FirstPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageFirst", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LeftPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPagePrevious", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[RightPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageNext", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LastPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageLast", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"]]]}], 
                 ButtonBoxOptions -> {Alignment -> {Automatic, 
                    FEPrivate`If[
                    FEPrivate`SameQ[
                    FEPrivate`$OperatingSystem, "Unix"], -0.4, -0.5]}, 
                   Appearance -> "Palette", 
                   ButtonFunction :> (FEPrivate`FrontEndExecute[
                    FrontEnd`FrontEndToken[
                    FrontEnd`ButtonNotebook[], #]]& ), Evaluator -> None, 
                   FrameMargins -> 0, ImageMargins -> 0, ImageSize -> 
                   Medium}], 
                
                DynamicModuleBox[{$CellContext`cells$$ = {}, \
$CellContext`tagFind$$ = False}, 
                 TagBox[
                  DynamicBox[
                   PopupMenuBox[
                    Dynamic[
                    0, With[{$CellContext`nb$ = ButtonNotebook[]}, 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; If[$CellContext`tagFind$$, 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowHeader", Next, 
                    CellTags, AutoScroll -> False], {#}], 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowNavigationBar", 
                    Next, CellStyle, AutoScroll -> False], {#}]]; 
                    SelectionMove[$CellContext`nb$, After, Cell, AutoScroll -> 
                    False]; NotebookWrite[$CellContext`nb$, 
                    Cell["", Deletable -> True, ShowCellBracket -> False], 
                    All]; NotebookDelete[$CellContext`nb$]; 
                    SelectionMove[$CellContext`nb$, 
                    If[$CellContext`tagFind$$, Previous, Next], 
                    Cell]]& ], $CellContext`cells$$, 
                    StyleBox[
                    RowBox[{
                    DynamicBox[
                    CurrentValue[{"CounterValue", "SlideShowNavigationBar"}]], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "SlideshowToolbarCounterText"]], 
                    DynamicBox[
                    
                    CurrentValue[{
                    "MaxCounterValue", "SlideShowNavigationBar"}]]}], 
                    "ControlStyle"], Appearance -> None, ImageSize -> 
                    Automatic], ImageSizeCache -> {50., {6., 18.}}], 
                  
                  EventHandlerTag[{
                   "MouseDown" :> 
                    Module[{$CellContext`cnt$, $CellContext`nb$ = 
                    InputNotebook[]}, $CellContext`cells$$ = {}; \
$CellContext`cnt$ = Apply[(
                    NotebookFind[$CellContext`nb$, #, All, #2, AutoScroll -> 
                    False]; CurrentValue[$CellContext`nb$, {
                    "CellCount", True}])& , {{
                    "SlideShowNavigationBar", CellStyle}, {
                    "SlideShowHeader", CellTags}}, {1}]; $CellContext`cnt$ = 
                    Apply[If[$CellContext`tagFind$$ = # == 
                    0, #2, #]& , $CellContext`cnt$]; 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; 
                    If[$CellContext`tagFind$$, $CellContext`cells$$ = 
                    Map[# -> StringJoin["Slide ", 
                    ToString[#]]& , 
                    Range[$CellContext`cnt$]], 
                    Do[NotebookFind[$CellContext`nb$, 
                    "SlideShowNavigationBar", Next, CellStyle, AutoScroll -> 
                    False]; SelectionMove[$CellContext`nb$, Next, Cell, 
                    AutoScroll -> False]; AppendTo[$CellContext`cells$$, 
                    ReplaceAll[
                    NotebookRead[$CellContext`nb$], Pattern[$CellContext`s, 
                    Blank[StyleBox]] :> With[{$CellContext`ss = Join[
                    Take[$CellContext`s, 1], 
                    DeleteCases[
                    Rest[$CellContext`s], 
                    Alternatives[
                    Blank[String], 
                    Blank[][FontColor, 
                    Blank[]]]]]}, 
                    
                    Condition[$CellContext`ss, 
                    True]]]], {$CellContext`cnt$}]; $CellContext`cells$$ = 
                    Replace[
                    Part[$CellContext`cells$$, All, 1], {BoxData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> $CellContext`c, TextData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> RowBox[
                    If[
                    
                    ListQ[$CellContext`c], $CellContext`c, \
{$CellContext`c}]]}, 1]; $CellContext`cells$$ = 
                    Thread[Range[$CellContext`cnt$] -> \
$CellContext`cells$$]]], PassEventsDown -> True, EvaluationOrder -> Before, 
                    PassEventsDown -> Automatic, PassEventsUp -> True}]], 
                 DynamicModuleValues :> {}]}}, AutoDelete -> False, 
              GridBoxItemSize -> {"Columns" -> {Automatic, Fit, Automatic}}]],
             "DockedCell", CellDynamicExpression :> If[CurrentValue[
                EvaluationNotebook[], {TaggingRules, "DisableController"}] === 
              True, Null, 
              (FrontEndExecute[
               FrontEnd`FrontEndToken[
                FrontEnd`InputNotebook[], #]]& )[
               Switch[
                ControllerState["Apple IR", {"B1", "B2"}], {True, 
                 Blank[]}, "ScrollPagePrevious", {
                 Blank[], True}, "ScrollPageNext", 
                Blank[], None]]], Magnification -> 0.75], 
          ScrollingOptions -> {
           "PagewiseDisplay" -> True, "VerticalScrollRange" -> Fit}, 
          ShowGroupOpener -> False, MenuSortingValue -> 1300], 
         Cell[
          StyleData["DockedCell"], Editable -> False, Evaluator -> "Local", 
          PageWidth -> WindowWidth, CellFrame -> {{0, 0}, {0, 0}}, 
          ShowSelection -> True, CellMargins -> {{0, 0}, {0, 0}}, 
          CellElementSpacings -> {
           "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 0}, 
          DynamicUpdating -> True, CellFrameMargins -> {{0, 0}, {0, 4}}, 
          ContextMenu -> None, ComponentwiseContextMenu -> {}, 
          ShowStringCharacters -> False, LineBreakWithin -> False, 
          Magnification -> 1, Background -> GrayLevel[0.97], 
          TooltipBoxOptions -> {TooltipDelay -> Automatic}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], MenuSortingValue -> 1, MenuCommandKey -> "1",
              FontFamily -> "Georgia", FontSize -> 36, FontWeight -> Plain, 
             FontColor -> RGBColor[0.796078, 0.0705882, 0]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{90, 100}, {10, 100}}, FontSize -> 54], 
            Cell[
             StyleData["Title", "SlideShow"]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], MenuSortingValue -> 100, MenuCommandKey -> 
             "2", FontFamily -> "Georgia", FontSize -> 24, FontWeight -> 
             "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{90, 100}, {100, 20}}, FontSize -> 32], 
            Cell[
             StyleData["Subtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], MenuSortingValue -> 200, 
             MenuCommandKey -> "3", FontFamily -> "Georgia", FontSize -> 20, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.2]], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 120}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 26], 
            Cell[
             StyleData["Subsubtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DateSection"], CellMargins -> {{30, 0}, {12, 24}}, 
             ShowStringCharacters -> False], 
            Cell[
             StyleData["DateSection", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 36}}, ShowStringCharacters -> 
             False, FontSize -> 21], 
            Cell[
             StyleData["DateSection", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Sections", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], CellMargins -> {{27, Inherited}, {8, 34}}, 
             CounterIncrements -> {"Chapter"}, MenuSortingValue -> 2410, 
             FontFamily -> "Georgia", FontSize -> 28, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098], CellTags -> "Chapter"], 
            Cell[
             StyleData["Chapter", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 60}, {20, 30}}, FontSize -> 36], 
            Cell[
             StyleData["Chapter", "SlideShow"]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> 0, MenuSortingValue -> 1200, 
             MenuCommandKey -> "4", FontFamily -> "Georgia", FontSize -> 24, 
             FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 14}, {30, 30}}, FontFamily -> "Georgia", 
             FontSize -> 34, FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[RightGuillemet]", 
             CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
             1300, MenuCommandKey -> "5", FontFamily -> "Georgia", FontSize -> 
             22, FontWeight -> Plain, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{80, 60}, {12, 20}}, FontSize -> 25], 
            Cell[
             StyleData["Subsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[RightGuillemet]", 
             MenuSortingValue -> 1400, MenuCommandKey -> "6", FontFamily -> 
             "Georgia", FontSize -> 20, FontWeight -> Plain, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{88, 60}, {0, 12}}, FontSize -> 22], 
            Cell[
             StyleData["Subsubsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "MoreExamplesSection", StyleDefinitions -> 
              StyleData["Subsubsection"]], CellDingbat -> None, 
             ShowGroupOpener -> True, 
             CellGroupingRules -> {"SectionGrouping", 45}, MenuSortingValue -> 
             2100, FontColor -> RGBColor[0.636862, 0.0564706, 0.]], 
            Cell[
             StyleData["MoreExamplesSection", "Presentation"], 
             CellMargins -> {{88, 60}, {20, 12}}], 
            Cell[
             StyleData["MoreExamplesSection", "SlideShow"], 
             WholeCellGroupOpener -> True, 
             CellMargins -> {{88, 60}, {20, 12}}]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], MenuSortingValue -> 2000, MenuCommandKey -> 
             "7", FontFamily -> "Georgia", FontSize -> 18], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{80, 20}, {12, 12}}, LineSpacing -> {1.25, 1}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["Text", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], MenuSortingValue -> 2010, 
             MenuCommandKey -> "8", FontFamily -> "Georgia", FontSize -> 18, 
             FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["MathCaption", "Presentation"], 
             CellMargins -> {{120, 12}, {6, 34}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 20], 
            Cell[
             StyleData["MathCaption", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "IntegrationMathCaption", StyleDefinitions -> 
              StyleData["MathCaption"]], CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Integration", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["IntegrationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}, FontSize -> 20], 
            Cell[
             StyleData["IntegrationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "AutomationMathCaption", StyleDefinitions -> 
              StyleData["IntegrationMathCaption"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Automation", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["AutomationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 20], 
            Cell[
             StyleData["AutomationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Comment", StyleDefinitions -> StyleData["Text"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Comment", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[1., 0.647059, 0], BoxFrame -> 1, 
                  FrameStyle -> RGBColor[1., 0.647059, 0], 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}, 
             MenuSortingValue -> 2200, FontSize -> 14], 
            Cell[
             StyleData["Comment", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16], 
            Cell[
             StyleData["Comment", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{60, Inherited}, {Inherited, Inherited}}, 
             StripStyleOnPaste -> True, DefaultFormatType -> 
             DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             MenuSortingValue -> 1700, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{120, Inherited}, {
               Inherited 1.75, Inherited 1.75}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["DisplayFormula", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Items", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2700, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["Item", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemParagraph"], MenuSortingValue -> 2710, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{120, 90}, {12, 12}}, LineSpacing -> {1.25, 0}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["ItemParagraph", "SlideShow"]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2720, FontFamily -> "Georgia", FontSize -> 
             18, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["ItemNumbered", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2730, FontFamily -> 
             "Georgia", FontSize -> 16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 21], 
            Cell[
             StyleData["Subitem", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemParagraph"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2740, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"], 
             CellMargins -> {{136, 90}, {10, 8}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2750, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemNumbered", "SlideShow"]]}, Open]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input and Output", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], MenuSortingValue -> 2020, MenuCommandKey -> 
             "9", FontSize -> 18], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Input", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], 
             CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
             LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6]], 
            Cell[
             StyleData["CellLabel", "Presentation"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "SlideShow"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShort"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShortInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLong"], FontFamily -> "Helvetica", 
             FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLongInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], MenuSortingValue -> 2030, FontSize -> 18], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Output", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], FontSize -> 18], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Print", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["MSG"], FontSize -> 16]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles of Links", "Section"], 
         Cell[
          StyleData["Link", "SlideShow"], FontSize -> 21], 
         Cell[
          StyleData["SearchLink", StyleDefinitions -> StyleData["Link"]]], 
         Cell[
          StyleData["FunctionLink"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Special Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], CellMargins -> {{100, 100}, {20, 20}}, 
             ShowStringCharacters -> False, MenuSortingValue -> 5000, 
             Magnification -> 1], 
            Cell[
             StyleData["Picture", "Presentation"], 
             CellMargins -> {{100, 100}, {20, 20}}, Magnification -> 1], 
            Cell[
             StyleData["Picture", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "PictureCaption", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> "\[FilledUpTriangle]", 
             CellMargins -> {{114, 100}, {15, 4}}, ShowStringCharacters -> 
             False, MenuSortingValue -> 5100, FontSize -> 14, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["PictureCaption", "Presentation"], 
             CellMargins -> {{114, 100}, {20, 4}}, FontSize -> 16], 
            Cell[
             StyleData["PictureCaption", "SlideShow"], 
             CellMargins -> {{114, 100}, {20, 4}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewTitle"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "Presentation"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewSection"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "Presentation"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterTagline"], CellMargins -> {{60, 90}, {15, 0}}, 
             MenuSortingValue -> 2420, FontFamily -> "Georgia", FontSize -> 
             20, FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["ChapterTagline", "Presentation"], 
             CellMargins -> {{90, 90}, {15, 0}}, FontSize -> 24], 
            Cell[
             StyleData["ChapterTagline", "SlideShow"]]}, Open]], 
         Cell[
          StyleData["PlotLabel"], FontFamily -> "Helvetica", FontSize -> 14], 
         Cell[
          StyleData["NonPrintButton"], 
          CellMargins -> {{128, Inherited}, {16, 0}}, FontFamily -> 
          "Helvetica", FontSize -> 12, FontColor -> GrayLevel[1], 
          ButtonBoxOptions -> {
           Background -> RGBColor[0.811765, 0.117647, 0.145098], 
            ButtonMargins -> 4}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"]], 
            Cell[
             StyleData["Program", "SlideShow"], 
             CellMargins -> {{116, 48}, {16, 16}}, FontSize -> 18]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Screencast", "Section", 
          CellChangeTimes -> {{3.520687019071189*^9, 
           3.5206870238431892`*^9}, {3.520687323526189*^9, 
           3.520687328236189*^9}}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "LargeChapter", StyleDefnitions -> StyleData["Chapter"]], 
             CellMargins -> {{27, Inherited}, {8, 34}}, MenuSortingValue -> 
             2430, FontFamily -> "Georgia", FontSize -> 30, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["LargeChapter", "SlideShow"], 
             CellMargins -> {{100, 10}, {15, 100}}, FontSize -> 48]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["LargeChapterTagline"], 
             CellMargins -> {{27, 60}, {30, 20}}, MenuSortingValue -> 2420, 
             FontFamily -> "Georgia", FontSize -> 26, FontWeight -> "Plain", 
             FontSlant -> "Italic", FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["LargeChapterTagline", "SlideShow"], 
             CellMargins -> {{100, 60}, {30, 15}}, FontSize -> 32]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["LargeOverviewTitle"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["LargeOverviewTitle", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 36, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["LargeOverviewSection"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["LargeOverviewSection", "SlideShow"], CellFrame -> 
             None, CellMargins -> {{120, 100}, {10, 10}}, 
             ReturnCreatesNewCell -> True, FontFamily -> "Georgia", FontSize -> 
             30, FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["LargeItem", StyleDefinitions -> StyleData["Item"]], 
             CellDingbat -> "\[RightGuillemet] ", LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2700, FontFamily -> "Georgia", FontSize -> 
             18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["LargeItem", "SlideShow"], 
             CellMargins -> {{100, 20}, {10, 10}}, FontSize -> 26]}, Open]]}, 
        Closed]]}, Open]]}, Visible -> False, FrontEndVersion -> 
  "8.0 for Microsoft Windows (64-bit) (October 15, 2011)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[629, 23, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1085, 42, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1916, 70, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[5477, 208, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[8040, 302, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[10426, 381, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[14086, 520, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 50214, 1326}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[629, 23, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[696, 26, 200, 4, 252, "Title"],
Cell[899, 32, 149, 5, 229, "Subsubtitle"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1085, 42, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[1152, 45, 33, 0, 109, "OverviewTitle"],
Cell[1188, 47, 110, 1, 47, "OverviewSection"],
Cell[1301, 50, 171, 5, 47, "OverviewSection"],
Cell[1475, 57, 162, 2, 47, "OverviewSection"],
Cell[1640, 61, 113, 1, 47, "OverviewSection"],
Cell[1756, 64, 123, 1, 47, "OverviewSection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1916, 70, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[2005, 75, 78, 1, 99, "Section"],
Cell[CellGroupData[{
Cell[2108, 80, 92, 1, 62, "Subsection"],
Cell[2203, 83, 377, 9, 79, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2617, 97, 200, 3, 62, "Subsection"],
Cell[2820, 102, 285, 6, 79, "Text"],
Cell[3108, 110, 115, 7, 170, "Program"],
Cell[3226, 119, 311, 6, 48, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3574, 130, 114, 1, 62, "Subsection"],
Cell[CellGroupData[{
Cell[3713, 135, 97, 1, 39, "Subsubsection"],
Cell[3813, 138, 203, 4, 79, "Text"],
Cell[4019, 144, 196, 10, 220, "Program"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4252, 159, 109, 1, 39, "Subsubsection"],
Cell[4364, 162, 231, 5, 77, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4644, 173, 95, 1, 62, "Subsection"],
Cell[4742, 176, 360, 6, 110, "Text"],
Cell[5105, 184, 176, 11, 270, "Program"],
Cell[5284, 197, 132, 4, 48, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5477, 208, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[5566, 213, 160, 5, 99, "Section"],
Cell[CellGroupData[{
Cell[5751, 222, 98, 1, 62, "Subsection"],
Cell[5852, 225, 319, 10, 79, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6208, 240, 48, 0, 62, "Subsection"],
Cell[6259, 242, 304, 6, 79, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6600, 253, 103, 1, 62, "Subsection"],
Cell[6706, 256, 458, 13, 119, "Text"],
Cell[CellGroupData[{
Cell[7189, 273, 104, 1, 39, "Subsubsection"],
Cell[7296, 276, 254, 5, 79, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7599, 287, 106, 1, 62, "Subsection"],
Cell[7708, 290, 271, 5, 79, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8040, 302, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[8129, 307, 130, 2, 99, "Section"],
Cell[CellGroupData[{
Cell[8284, 313, 44, 0, 62, "Subsection"],
Cell[8331, 315, 377, 7, 79, "Text"],
Cell[8711, 324, 303, 9, 170, "Program"],
Cell[9017, 335, 201, 4, 48, "Text"],
Cell[9221, 341, 177, 4, 95, "Program"],
Cell[9401, 347, 361, 6, 110, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9799, 358, 45, 0, 62, "Subsection"],
Cell[9847, 360, 288, 8, 79, "Text"],
Cell[10138, 370, 227, 4, 79, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10426, 381, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[10515, 386, 79, 1, 99, "Section"],
Cell[CellGroupData[{
Cell[10619, 391, 118, 1, 62, "Subsection"],
Cell[10740, 394, 267, 5, 110, "Text"],
Cell[11010, 401, 272, 5, 79, "Text"],
Cell[11285, 408, 193, 8, 170, "Program"],
Cell[11481, 418, 233, 5, 48, "Text"],
Cell[11717, 425, 165, 11, 270, "Program"],
Cell[11885, 438, 401, 13, 84, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12323, 456, 115, 1, 62, "Subsection"],
Cell[12441, 459, 130, 3, 48, "Text"],
Cell[12574, 464, 134, 7, 170, "Program"],
Cell[12711, 473, 346, 9, 84, "Text"],
Cell[13060, 484, 188, 8, 170, "Program"],
Cell[13251, 494, 216, 4, 79, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13504, 503, 107, 1, 62, "Subsection"],
Cell[13614, 506, 411, 7, 79, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14086, 520, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[14175, 525, 90, 1, 99, "Section"],
Cell[CellGroupData[{
Cell[14290, 530, 81, 2, 62, "Subsection"],
Cell[14374, 534, 265, 5, 79, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14676, 544, 43, 0, 62, "Subsection"],
Cell[14722, 546, 274, 5, 110, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
